==> haskell-aws-0.24-124-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-aws.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aws
version:              0.24
visibility:           public
id:                   aws-0.24-6LtOBc8J8AZ8UbW8vYBWHz
key:                  aws-0.24-6LtOBc8J8AZ8UbW8vYBWHz
license:              BSD-3-Clause
copyright:            See contributors list in README and LICENSE file
maintainer:           aristidb@gmail.com
author:               Aristid Breitkreuz, contributors see README
homepage:             http://github.com/aristidb/aws
synopsis:             Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.

category:             Network, Web, AWS, Cloud, Distributed Computing
abi:                  7a74b46d7700e214d6bab387021a4f86
exposed:              True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.AddUserToGroup Aws.Iam.Commands.CreateAccessKey
    Aws.Iam.Commands.CreateGroup Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteGroup
    Aws.Iam.Commands.DeleteGroupPolicy Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetGroupPolicy
    Aws.Iam.Commands.GetUser Aws.Iam.Commands.GetUserPolicy
    Aws.Iam.Commands.ListAccessKeys Aws.Iam.Commands.ListGroupPolicies
    Aws.Iam.Commands.ListGroups Aws.Iam.Commands.ListMfaDevices
    Aws.Iam.Commands.ListUserPolicies Aws.Iam.Commands.ListUsers
    Aws.Iam.Commands.PutGroupPolicy Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.RemoveUserFromGroup
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateGroup
    Aws.Iam.Commands.UpdateUser Aws.Iam.Core Aws.Iam.Internal
    Aws.Network Aws.S3 Aws.S3.Commands Aws.S3.Commands.CopyObject
    Aws.S3.Commands.DeleteBucket Aws.S3.Commands.DeleteObject
    Aws.S3.Commands.DeleteObjectVersion Aws.S3.Commands.DeleteObjects
    Aws.S3.Commands.GetBucket Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutBucketVersioning Aws.S3.Commands.PutObject
    Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core

import-dirs:          /usr/lib/ghc-9.2.8/site-local/aws-0.24
library-dirs:         /usr/lib/ghc-9.2.8/site-local/aws-0.24
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aws
hs-libraries:         HSaws-0.24-6LtOBc8J8AZ8UbW8vYBWHz
depends:
    aeson-2.1.2.1-1R35DvuKsJwFudsOlCM6yV
    attoparsec-0.14.4-l6gpYVAuXa4krkAJlMwbn base-4.16.4.0
    base16-bytestring-1.0.2.0-KWjk12Kc0JO2Mp5RJvDvOx
    base64-bytestring-1.2.1.0-IHt64Gotm2vFOEZhD5akU7
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK
    byteable-0.1.1-2aVcTelA6XA9YKIvhjRaxC bytestring-0.11.4.0
    case-insensitive-1.2.1.0-2Tjf2PFkxP43DkqVUMYCmf
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22
    conduit-1.3.5-9fqCSsgtXVG2zpv5ZVEi4s
    conduit-extra-1.3.6-AEwfYIT97IN5iosArwGxsb containers-0.6.5.1
    cryptonite-0.30-2G7emN3aUjLCPswZX3R9DV
    data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB directory-1.3.6.2
    exceptions-0.10.4 filepath-1.4.2.2
    http-client-tls-0.3.6.3-vm9lZXKKPQG6YiMQwXwb7
    http-conduit-2.3.8.3-1nsQ6LY8l6ZCKHc2yiI82m
    http-types-0.12.4-B3znMwHTe3dL304Bd3IJgZ
    lifted-base-0.2.3.12-KEmYXLYHLpPF9hCSICqvW8
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    monad-control-1.0.3.1-3jkrHBLrPTk3GVH33R4YSx mtl-2.2.2
    network-3.1.4.0-IeiVJWXSaeWHp5XfJw1SH3
    network-bsd-2.8.1.0-78V9yGSAC2D3vLyNkVoFW6
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7
    resourcet-1.2.6-L3rnNUXQIyNIGkCgFQVXFM
    safe-0.3.21-4QyPpELCc0N1ZMTeAcwgiX
    scientific-0.3.7.0-DmJatUkkzP1HryFyYrhDfx
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2
    unordered-containers-0.2.20-Kaqz4YtssULDpEsD0of7Qa
    utf8-string-1.0.2-9i4m1tpDbmh81tMCrQ25jI
    vector-0.13.1.0-HyaXkpW7aOFHhHqdwTfvZq
    xml-conduit-1.9.1.3-78hprMCLgMFFWPQU2FN158

haddock-interfaces:   /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html:         /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aws-0.24-132-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-aws.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aws
version:              0.24
visibility:           public
id:                   aws-0.24-BHdasWteNg6IJU7K72tqrc
key:                  aws-0.24-BHdasWteNg6IJU7K72tqrc
license:              BSD-3-Clause
copyright:            See contributors list in README and LICENSE file
maintainer:           aristidb@gmail.com
author:               Aristid Breitkreuz, contributors see README
homepage:             http://github.com/aristidb/aws
synopsis:             Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.

category:             Network, Web, AWS, Cloud, Distributed Computing
abi:                  3b4965697598e9ee61555af6942996ad
exposed:              True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.AddUserToGroup Aws.Iam.Commands.CreateAccessKey
    Aws.Iam.Commands.CreateGroup Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteGroup
    Aws.Iam.Commands.DeleteGroupPolicy Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetGroupPolicy
    Aws.Iam.Commands.GetUser Aws.Iam.Commands.GetUserPolicy
    Aws.Iam.Commands.ListAccessKeys Aws.Iam.Commands.ListGroupPolicies
    Aws.Iam.Commands.ListGroups Aws.Iam.Commands.ListMfaDevices
    Aws.Iam.Commands.ListUserPolicies Aws.Iam.Commands.ListUsers
    Aws.Iam.Commands.PutGroupPolicy Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.RemoveUserFromGroup
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateGroup
    Aws.Iam.Commands.UpdateUser Aws.Iam.Core Aws.Iam.Internal
    Aws.Network Aws.S3 Aws.S3.Commands Aws.S3.Commands.CopyObject
    Aws.S3.Commands.DeleteBucket Aws.S3.Commands.DeleteObject
    Aws.S3.Commands.DeleteObjectVersion Aws.S3.Commands.DeleteObjects
    Aws.S3.Commands.GetBucket Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutBucketVersioning Aws.S3.Commands.PutObject
    Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core

import-dirs:          /usr/lib/ghc-9.2.8/site-local/aws-0.24
library-dirs:         /usr/lib/ghc-9.2.8/site-local/aws-0.24
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aws
hs-libraries:         HSaws-0.24-BHdasWteNg6IJU7K72tqrc
depends:
    aeson-2.1.2.1-BDwFFwggpmOFR96vAdYTat
    attoparsec-0.14.4-HEPxPDNq5mJKRZZEtIXOMd base-4.16.4.0
    base16-bytestring-1.0.2.0-9AKEfJpeJHOK2mzYhoV7G4
    base64-bytestring-1.2.1.0-FdWgvlJbicB4WMe5vVN4jG
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK
    byteable-0.1.1-2aVcTelA6XA9YKIvhjRaxC bytestring-0.11.4.0
    case-insensitive-1.2.1.0-BBCkGXkqh3nGRz3m4HFNUT
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22
    conduit-1.3.5-L0mNMsdu9UG80ANe4qO3ja
    conduit-extra-1.3.6-EYhdqEfvmIN7ClpVheXInl containers-0.6.5.1
    cryptonite-0.30-B8lqKo2bgZjIAiaKsp19j7
    data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB directory-1.3.6.2
    exceptions-0.10.4 filepath-1.4.2.2
    http-client-tls-0.3.6.3-2ybD7Q8IjvzLtHCrozGuNr
    http-conduit-2.3.8.3-2Avymhb76G425d5MK9oJsw
    http-types-0.12.4-1kre27HuLExE9CKvtupIO2
    lifted-base-0.2.3.12-HS4U5p9kOMcASMLdVxJFLH
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    monad-control-1.0.3.1-ATKYMnkFwQRIHXjVMGqTnF mtl-2.2.2
    network-3.1.4.0-2VaTeXEywlqHC2pV2iXMik
    network-bsd-2.8.1.0-8odhSoml6qLDJTfWl3Ma9Z
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7
    resourcet-1.2.6-5BnvDTZXmqJCsWMY1Zflgy
    safe-0.3.21-iv9yHEgDynJNZkwcC9KXL
    scientific-0.3.7.0-KUJ0yQBDqbB75MLhDe7uzc
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2
    unordered-containers-0.2.20-FcLWwyBCSKkJfk374YGHrL
    utf8-string-1.0.2-9i4m1tpDbmh81tMCrQ25jI
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh
    xml-conduit-1.9.1.3-LXZLRjrO0miFmIDwMUDhxT

haddock-interfaces:   /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html:         /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
